var indexSectionsWithContent =
{
  0: ":_abcdefghijklmnopqrstuvwxyz",
  1: "abcdefghijklmnopqrstuvwxyz",
  2: "co",
  3: "abcdefghijklmnopqrstuvwxyz",
  4: "abcdefghijklmnopqrstuvwx",
  5: "abcdefghijklmnopqrstuvwxyz",
  6: "abcdefghiklmnoprstuv",
  7: "abcdefghilmnoprstuvwxz",
  8: "abcdefghijklmnopqrstuvwxyz",
  9: "_cio",
  10: "dlt"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "defines",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Macros",
  10: "Pages"
};

